==> v0.4.0.tar.gz: elasticsearch/modules/elasticsearch/src/main/java/org/elasticsearch/index/query/json/SpanOrJsonQueryBuilder.java <==
/*
 * Licensed to Elastic Search and Shay Banon under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. Elastic Search licenses this
 * file to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.elasticsearch.index.query.json;

import org.elasticsearch.index.query.QueryBuilderException;
import org.elasticsearch.util.json.JsonBuilder;

import java.io.IOException;
import java.util.ArrayList;

/**
 * @author kimchy (Shay Banon)
 */
public class SpanOrJsonQueryBuilder extends BaseJsonQueryBuilder implements JsonSpanQueryBuilder {

    private ArrayList<JsonSpanQueryBuilder> clauses = new ArrayList<JsonSpanQueryBuilder>();

    private float boost = -1;

    public SpanOrJsonQueryBuilder clause(JsonSpanQueryBuilder clause) {
        clauses.add(clause);
        return this;
    }

    public SpanOrJsonQueryBuilder boost(float boost) {
        this.boost = boost;
        return this;
    }

    @Override protected void doJson(JsonBuilder builder) throws IOException {
        if (clauses.isEmpty()) {
            throw new QueryBuilderException("Must have at least one clause when building a spanOr query");
        }
        builder.startObject(SpanOrJsonQueryParser.NAME);
        builder.startArray("clauses");
        for (JsonSpanQueryBuilder clause : clauses) {
            clause.toJson(builder);
        }
        builder.endArray();
        if (boost != -1) {
            builder.field("boost", boost);
        }
        builder.endObject();
    }
}

==> v0.5.1.tar.gz: elasticsearch/modules/elasticsearch/src/main/java/org/elasticsearch/index/query/json/SpanOrJsonQueryBuilder.java <==
/*
 * Licensed to Elastic Search and Shay Banon under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. Elastic Search licenses this
 * file to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.elasticsearch.index.query.json;

import org.elasticsearch.index.query.QueryBuilderException;
import org.elasticsearch.util.json.JsonBuilder;

import java.io.IOException;
import java.util.ArrayList;

/**
 * @author kimchy (Shay Banon)
 */
public class SpanOrJsonQueryBuilder extends BaseJsonQueryBuilder implements JsonSpanQueryBuilder {

    private ArrayList<JsonSpanQueryBuilder> clauses = new ArrayList<JsonSpanQueryBuilder>();

    private float boost = -1;

    public SpanOrJsonQueryBuilder clause(JsonSpanQueryBuilder clause) {
        clauses.add(clause);
        return this;
    }

    public SpanOrJsonQueryBuilder boost(float boost) {
        this.boost = boost;
        return this;
    }

    @Override protected void doJson(JsonBuilder builder, Params params) throws IOException {
        if (clauses.isEmpty()) {
            throw new QueryBuilderException("Must have at least one clause when building a spanOr query");
        }
        builder.startObject(SpanOrJsonQueryParser.NAME);
        builder.startArray("clauses");
        for (JsonSpanQueryBuilder clause : clauses) {
            clause.toJson(builder, params);
        }
        builder.endArray();
        if (boost != -1) {
            builder.field("boost", boost);
        }
        builder.endObject();
    }
}
